@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.04
+0.05
 
 =head1 SYNOPSIS
 
@@ -64,6 +64,7 @@ Additional config params.
     apps => [...], # See SYNOPSIS
     log => {
       file => '/path/to/log/file.log',
+      level => 'debug', # debug, info, warn, ...
       combined => 1, # true to make all applications log to the same file
     },
     hypnotoad => {
@@ -106,7 +107,7 @@ L<Toadfarm::Plugin::Reload>.
 use Mojo::Base 'Mojolicious';
 use Mojo::Util 'class_to_path';
 
-our $VERSION = eval '0.04';
+our $VERSION = eval '0.05';
 
 =head1 METHODS
 
@@ -120,8 +121,13 @@ sub startup {
   my $self = shift;
   my $config = $ENV{MOJO_CONFIG} ? $self->plugin('Config') : {};
 
-  $self->log->path($config->{log}{file}) if $config->{log}{file};
-  delete $self->log->{handle}; # Not sure why I need to reset the handle...
+  if($config->{log}{file}) {
+    my $log = Mojo::Log->new;
+    $log->path($config->{log}{file});
+    $log->level($config->{log}{level} || 'info');
+    $self->log($log);
+  }
+
   $self->_start_apps(@{ $config->{apps} }) if $config->{apps};
   $self->_start_plugins(@{ $config->{plugins} }) if $config->{plugins};
 }
@@ -131,6 +137,10 @@ sub _start_apps {
   my $routes = $self->routes;
   my $n = 0;
 
+  if($self->config->{log}{combined}) {
+    $self->log->info('All apps will log to ' .$self->config->{log}{file});
+  }
+
   while(@_) {
     my($path, $rules) = (shift @_, shift @_);
     my($app, $r, $request_base, @over);
@@ -146,15 +156,19 @@ sub _start_apps {
       push @over, "return 0 unless +(\$h->header('$name') // '') eq '$value';\n";
     }
 
-    $r = $routes->route('/*original_path')->detour(app => $app, original_path => '');
+    $r = $routes->route('/')->detour(app => $app);
 
     if(@over) {
+      $app->log->info("Mounting $path with conditions");
       unshift @over, "sub { my \$h = \$_[1]->req->headers;\n";
       push @over, "\$_[1]->req->url->base(Mojo::URL->new('$request_base'));" if $request_base;
       push @over, "return 1; }";
       $routes->add_condition("toadfarm_condition_$n", => eval "@over" || die "@over: $@");
       $r->over("toadfarm_condition_$n");
     }
+    else {
+      $app->log->info("Mounting $path without condition");
+    }
 
     $n++;
   }
@@ -169,6 +183,7 @@ sub _start_plugins {
 
   while(@_) {
     my($plugin, $config) = (shift @_, shift @_);
+    $self->log->info("Loading plugin $plugin");
     $self->plugin($plugin, $config);
   }
 }
